==> james-project-3.4.0-source-release.zip: james-project-3.4.0/server/container/spring/src/main/java/org/apache/james/container/spring/lifecycle/ConfigurableBeanPostProcessor.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/
package org.apache.james.container.spring.lifecycle;

import org.apache.commons.configuration2.HierarchicalConfiguration;
import org.apache.james.lifecycle.api.Configurable;

/**
 * Inject Commons Configuration to beans which implement the Configurable
 * interface
 */
public class ConfigurableBeanPostProcessor extends AbstractLifecycleBeanPostProcessor<Configurable> {

    private ConfigurationProvider provider;

    public void setConfigurationProvider(ConfigurationProvider provider) {
        this.provider = provider;
    }

    @Override
    protected Class<Configurable> getLifeCycleInterface() {
        return Configurable.class;
    }

    @Override
    protected void executeLifecycleMethodBeforeInit(Configurable bean, String beanname) throws Exception {
        HierarchicalConfiguration config = provider.getConfiguration(beanname);
        bean.configure(config);
    }

    @Override
    protected void executeLifecycleMethodAfterInit(Configurable bean, String beanname) throws Exception {
        // Do nothing.
    }

}

==> james-project-3.8.2-source-release.zip: james-project-3.8.2/server/container/spring/src/main/java/org/apache/james/container/spring/lifecycle/ConfigurableBeanPostProcessor.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/
package org.apache.james.container.spring.lifecycle;

import org.apache.commons.configuration2.HierarchicalConfiguration;
import org.apache.commons.configuration2.tree.ImmutableNode;
import org.apache.james.lifecycle.api.Configurable;

/**
 * Inject Commons Configuration to beans which implement the Configurable
 * interface
 */
public class ConfigurableBeanPostProcessor extends AbstractLifecycleBeanPostProcessor<Configurable> {

    private ConfigurationProvider provider;

    public void setConfigurationProvider(ConfigurationProvider provider) {
        this.provider = provider;
    }

    @Override
    protected Class<Configurable> getLifeCycleInterface() {
        return Configurable.class;
    }

    @Override
    protected void executeLifecycleMethodBeforeInit(Configurable bean, String beanname) throws Exception {
        HierarchicalConfiguration<ImmutableNode> config = provider.getConfiguration(beanname);
        bean.configure(config);
    }

    @Override
    protected void executeLifecycleMethodAfterInit(Configurable bean, String beanname) throws Exception {
        // Do nothing.
    }

}
